package com.emperador.exoplayer

import android.app.Activity
import android.content.Intent
import android.util.Log
import com.emperador.exoplayer.service.MusicService
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar
import android.content.Context.ACTIVITY_SERVICE
import android.app.ActivityManager


class ExoplayerPlugin(private var activity: Activity) : MethodCallHandler {


    companion object {

        @JvmStatic
        fun registerWith(registrar: Registrar) {
            val channel = MethodChannel(registrar.messenger(), "exoplayer")
            channel.setMethodCallHandler(ExoplayerPlugin(registrar.activity()))
        }

    }

    override fun onMethodCall(call: MethodCall, result: Result) {
        Log.i("ExoplayerPlugin call ->", call.method)
        when {
            call.method == "startService" -> mStartService(call)
            call.method == "play" -> play()
            call.method == "stopService" -> stop()
            call.method == "pause" -> pause()
            else -> result.notImplemented()
        }
    }


    private fun mStartService(call: MethodCall) {

        if (isMyServiceRunning(MusicService::class.java)) {
            Log.e("ExoplayerPlugin", "Service already started")
            return
        }

        val type: Int = call.argument("type")!!
        val url: String = call.argument("url")!!

        val intent = Intent(activity, MusicService::class.java)
        intent.putExtra("type", type)
        intent.putExtra("url", url)
        activity.startService(intent)

    }

    private fun play() {
        val i = Intent()
        i.action = MusicService.ACTION_PLAY
        activity.sendBroadcast(i)
    }

    private fun stop() {
        val i = Intent()
        i.action = MusicService.ACTION_STOP
        activity.sendBroadcast(i)

        val lintent = Intent(activity, MusicService::class.java)
        activity.stopService(lintent)
    }

    private fun pause() {
        val i = Intent()
        i.action = MusicService.ACTION_PAUSE
        activity.sendBroadcast(i)
    }

    private fun isMyServiceRunning(serviceClass: Class<*>): Boolean {
        val manager = activity.getSystemService(ACTIVITY_SERVICE) as ActivityManager?
        for (service in manager!!.getRunningServices(Integer.MAX_VALUE)) {
            if (serviceClass.name == service.service.className) {
                return true
            }
        }
        return false
    }
}
